from typing import Optional, Generator, Tuple
from unittest import mock

import pytest

from gcs_migration.models import GsiAuthzConfiguration
from gcs_migration.util import AuthorizeSharing


@pytest.fixture
def authorization_response_success(
    sharing_local_user: str, test_user_cert_subject: str
) -> Tuple[Optional[str], str, Optional[int]]:
    return sharing_local_user, test_user_cert_subject, 0


@pytest.fixture
def authorize_sharing(
    authorization_response_success: Tuple[Optional[str], str, Optional[int]]
) -> Generator["AuthorizeSharing", None, None]:
    with mock.patch("gcs_migration.util.authorize_sharing.ctypes"), mock.patch.object(
        AuthorizeSharing, "map_and_authorize_sharing"
    ) as mock_map_and_authorize_sharing:
        mock_map_and_authorize_sharing.return_value = authorization_response_success
        yield AuthorizeSharing(GsiAuthzConfiguration())
