from typing import Optional

import pytest

from gcs_migration.parsers import GsiAuthzParser
from tests.fixtures.gsi_authz_config import CalloutLine, GsiAuthzConfFixtureCreator


@pytest.mark.parametrize("gridmap", [None, "/etc/grid-security/grid-mapfile"])
def test_parse_cilogon(
    gsi_authz_conf: GsiAuthzConfFixtureCreator,
    cilogon_callout: CalloutLine,
    gridmap: Optional[str],
) -> None:
    config_path = gsi_authz_conf([cilogon_callout])

    parser = GsiAuthzParser()
    callouts = parser.parse(config_path, gridmap, None)

    assert callouts is not None
    result = callouts[0]

    assert result == cilogon_callout.config
    if gridmap:
        assert callouts[1] is None
    else:
        assert len(callouts) == 1


@pytest.mark.parametrize("gridmap", [None, "/etc/grid-security/grid-mapfile"])
def test_parse_myproxy(
    gsi_authz_conf: GsiAuthzConfFixtureCreator,
    myproxy_callout: CalloutLine,
    gridmap: Optional[str],
) -> None:
    config_path = gsi_authz_conf([myproxy_callout])
    parser = GsiAuthzParser()

    callouts = parser.parse(config_path, gridmap, None)

    assert callouts is not None
    result = callouts[0]
    assert result == myproxy_callout.config

    if gridmap:
        assert callouts[1] is None
    else:
        assert len(callouts) == 1


@pytest.mark.parametrize("gridmap", [None, "/etc/grid-security/grid-mapfile"])
def test_parse_myproxy_no_env(
    gsi_authz_conf: GsiAuthzConfFixtureCreator,
    myproxy_callout_without_env: CalloutLine,
    gridmap: Optional[str],
) -> None:
    config_path = gsi_authz_conf([myproxy_callout_without_env])
    parser = GsiAuthzParser()

    callouts = parser.parse(config_path, gridmap, None)

    assert callouts is not None
    result = callouts[0]
    assert result == myproxy_callout_without_env.config

    if gridmap:
        assert callouts[1] is None
    else:
        assert len(callouts) == 1
